==> jc-1.4.0.tar.gz: javax/print/attribute/AttributeSetUtilities__24SynchronizedDocAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$SynchronizedDocAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a977668ae8c65227 javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet
// @dep_class 731709561cb4f021 javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24SynchronizedAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_DocAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$method$_init$bdf5415a099a64cc(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/AttributeSetUtilities__24SynchronizedDocAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$SynchronizedDocAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a977668ae8c65227 javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet
// @dep_class 731709561cb4f021 javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24SynchronizedAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_DocAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$method$_init$bdf5415a099a64cc(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedDocAttributeSet_H_ */
